@@ -2,7 +2,7 @@
 # Display functions for LemonLDAP::NG Portal
 package Lemonldap::NG::Portal::Main::Display;
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.1';
 
 package Lemonldap::NG::Portal::Main;
 use strict;
@@ -418,11 +418,7 @@ sub display {
     }
 
     # Additional $req param
-    %templateParams = (
-        %templateParams,
-        TROVER => $self->trOver,
-        %{ $req->{customParameters} // {} },
-    );
+    %templateParams = ( %templateParams, %{ $req->{customParameters} // {} }, );
 
     for my $session_key ( keys %{ $req->{sessionInfo} } ) {
         $templateParams{ "session_" . $session_key } =
